<?php

###############################################################################
# hellenic.php
# This is the Hellenic language page for GeekLog!
# Revision No: 5 
# Date 21/04/2005
#
# + Compatible with Geeklog 1.3.11 + other corrections
# + Geeklog?s new URL added
# + Formalization of the language completed
# + Language is now more ?Modern Greek Friendly?
# + Removal of the most pre-modern Greek (before 1981) words.
#  
#
# Copyright (C) 2002-2005 Master of Death
# mzozd@ad2u.gr & mzozd@hotmail.com
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

$LANG_CHARSET = 'iso-8859-7';

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

###############################################################################
# USER PHRASES - These are file phrases used in end user scripts
###############################################################################

###############################################################################
# lib-common.php

$LANG01 = array(
    1 => ' /:',
    2 => ' ',
    3 => '',
    4 => '',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => ' :',
    10 => ' ',
    11 => '',
    12 => '',
    13 => '',
    14 => '',
    15 => '',
    16 => '',
    17 => '',
    18 => ' SQL',
    19 => '',
    20 => ' :',
    21 => ' ',
    22 => ' ',
    23 => ' ',
    24 => '',
    25 => '',
    26 => '      .         ',
    27 => '  ',
    28 => '',
    29 => ' .',
    30 => ' ',
    31 => '  HTML:',
    32 => ',   ',
    33 => ',       .',
    34 => '',
    35 => '',
    36 => '',
    37 => '       ',
    38 => ' ',
    39 => '',
    40 => '',
    41 => '',
    42 => ':',
    43 => '  ',
    44 => '',
    45 => ' MySQL  ',
    46 => ' MySQL  ',
    47 => ' ',
    48 => '    ',
    49 => '   ',
    50 => ' SQL  ',
    51 => '',
    52 => '',
    53 => '  ',
    54 => '     ',
    55 => ' ',
    56 => '',
    57 => ' ',
    58 => '',
    59 => "    ,     <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\"> </a>",
    60 => ' ',
    61 => '  ',
    62 => '',
    63 => ' ',
    64 => '   8   ',
    65 => '    ',
    66 => '',
    67 => '   ',
    68 => ' ',
    69 => '',
    70 => '',
    71 => ' ',
    72 => '',
    73 => '',
    74 => '',
    75 => ' ',
    76 => ' ',
    77 => ' ',
    78 => '',
    79 => ' ',
    80 => '  ',
    81 => '  ',
    82 => '',
    83 => '',
    84 => '',
    85 => ' 48 ',
    86 => '  ',
    87 => ' 2 ',
    88 => '',
    89 => '',
    90 => ' ',
    91 => '   ',
    92 => '',
    93 => '  ',
    94 => '            ',
    95 => '   ',
    96 => '',
    97 => ' ',
    98 => ' ',
    99 => '',
    100 => '   ',
    101 => '',
    102 => '',
    103 => '   ',
    104 => '',
    105 => '  ',
    106 => '',
    107 => '     GL',
    108 => ' Cache',
    109 => '     ',
    110 => '       ',
    111 => '',
    112 => ' ',
    113 => '',
    114 => 'TRACKBACKS',
    115 => 'No new trackback comments',
    116 => 'Trackback',
    117 => 'Directory',
    118 => 'Please continue reading on the next page:',
    119 => "Lost your <a href=\"{$_CONF['site_url']}/users.php?mode=getpassword\" rel=\"nofollow\">password</a>?",
    120 => 'Permanent link to this comment',
    121 => 'Comments (%d)',
    122 => 'Trackbacks (%d)',
    123 => 'All HTML is allowed',
    124 => 'Click to delete all checked items',
    125 => 'Are you sure you want to Delete all checked items?',
    126 => 'Select or de-select all items',
    127 => 'Permalink',
    128 => 'Login with OpenID:',
    129 => 'Configuration',
    130 => 'Webservices'
);

###############################################################################
# comment.php

$LANG03 = array(
    1 => '   ',
    2 => ' ',
    3 => '',
    4 => ' ',
    5 => ' ',
    6 => '           .           .',
    7 => '     ',
    8 => "  .        {$_CONF['commentspeedlimit']}    ",
    9 => '',
    10 => ' ',
    11 => '   ',
    12 => '   :   .        .',
    13 => '  ',
    14 => '',
    15 => 'Report this post',
    16 => '',
    17 => '',
    18 => '',
    19 => '          ',
    20 => '           ',
    21 => '  ,           .',
    22 => '         ',
    23 => '      ',
    24 => ' ',
    25 => ' ()           ;',
    26 => '%s     :',
    27 => '  ',
    28 => 'Preview Changes',
    29 => 'Submit Changes',
    30 => 'Edited on',
    31 => 'by',
    32 => 'Editing a Comment',
    33 => 'Editing a Comment Submission',
    34 => 'Preview Submission Changes',
    35 => 'Save Changes to Queue',
    36 => 'Notify me of new replies',
    37 => 'New Comment Reply',
    38 => 'A reply has been made to your comment \'%s\'.',
    39 => 'You may view the comment thread at the following address:',
    40 => 'If you wish to receive no further notifications of replies, visit the following link:',
    41 => 'Hello %s,',
    42 => 'Unsubscribe',
    43 => 'Unsubscribe from reply notifications',
    44 => 'Your Name'
);

###############################################################################
# users.php

$LANG04 = array(
    1 => ' ',
    2 => ' ',
    3 => ' ',
    4 => '',
    5 => '  ',
    6 => '',
    7 => '',
    8 => ' PGP',
    9 => ' ',
    10 => ' 10   /',
    11 => '    / ',
    12 => '  ',
    13 => '    ',
    14 => '      .     .          .',
    15 => "     {$_CONF['site_name']}   .     .     .",
    16 => '    ',
    17 => '   ',
    18 => '        ',
    19 => '          ',
    20 => '        ',
    21 => '',
    22 => "  {$_CONF['site_name']}!",
    23 => "              {$_CONF['site_name']}      .     ,         .     <b><i> </i></b>       .",
    24 => '          .',
    25 => '   ;',
    26 => '           .             .',
    27 => ' ',
    28 => '    ',
    29 => ' ',
    30 => ' ',
    31 => '  ,    ',
    32 => '',
    33 => '  ',
    34 => '     ',
    35 => '  ',
    36 => '  http://',
    37 => '   ',
    38 => '   ,      ',
    39 => '  PGP  ',
    40 => '     ',
    41 => '/  ',
    42 => ' ',
    43 => '  ',
    44 => '  ',
    45 => '   /',
    46 => '    /',
    47 => '    /',
    48 => '',
    49 => '     ',
    50 => '       ',
    51 => '   ',
    52 => '  ',
    53 => '     ',
    54 => '             .',
    55 => '      ,     .    ,           .       .',
    56 => '',
    57 => ' ',
    58 => ' ',
    59 => ' ',
    60 => '     ;',
    61 => '      ;',
    62 => '   100',
    63 => "         .              {$_CONF['site_name']}",
    64 => '  ',
    65 => '    ',
    66 => "        .    .  <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\"> </a>;",
    67 => ' ',
    68 => '   ',
    69 => '                ',
    70 => "           {$_CONF['site_name']}",
    71 => "     {$_CONF['site_name']}                .           <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\"></a>  {$_CONF['site_name']}.     ,         ",
    72 => '',
    73 => '',
    74 => '    ',
    75 => '       /',
    76 => '      ,                 .       !',
    77 => '',
    78 => '   ',
    79 => '       ',
    80 => '',
    81 => '  ',
    82 => ' 10   / ',
    83 => '    ',
    84 => ' :',
    85 => ' :',
    86 => '     ',
    87 => '    ',
    88 => ", ( ),           \"%s\"   {$_CONF['site_name']}, <{$_CONF['site_url']}>.\n\n            :\n\n",
    89 => "                    (          ).\n\n",
    90 => '          .               .',
    91 => '  ',
    92 => '   ',
    93 => '         %d .        %d       .',
    94 => '  "%s"',
    95 => '  " "           .        <strong></strong>            "Anonymous".',
    96 => ' ',
    97 => '  ',
    98 => ' ()       ;              .   ()   " "    .',
    99 => '  ',
    100 => '    ',
    101 => '     ',
    102 => '    ',
    103 => '    ',
    104 => '    ',
    105 => '    "    ',
    106 => '',
    107 => '    ',
    108 => 'Confirm new password',
    109 => 'Enter the New password again here',
    110 => 'Current Password',
    111 => 'Please enter your Current password',
    112 => 'You have exceeded the number of allowed login attempts.  Please try again later.',
    113 => 'Login Attempt Failed',
    114 => 'Account Disabled',
    115 => 'Your account has been disabled, you may not login. Please contact an Administrator.',
    116 => 'Account Awaiting Activation',
    117 => 'Your account is currently awaiting activation by an administrator. You will not be able to login until your account has been approved.',
    118 => "Your {$_CONF['site_name']} account has now been activated by an administrator. You may now login to the site at the url below using your username (<username>) and password as previously emailed to you.",
    119 => 'If you have forgotten your password, you may request a new one at this url:',
    120 => 'Account Activated',
    121 => 'Service',
    122 => 'Sorry, new user registration is disabled',
    123 => "Are you a <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">new user</a>?",
    124 => 'Confirm Email',
    125 => 'You have to enter the same email address in both fields!',
    126 => 'Please repeat for confirmation',
    127 => 'To change any of these settings, you will have to enter your current password.',
    128 => 'Your Name',
    129 => 'Password &amp; Email',
    130 => 'About You',
    131 => 'Daily Digest Options',
    132 => 'Daily Digest Feature',
    133 => 'Comment Display',
    134 => 'Comment Options',
    135 => '<li>Default mode for how comments will be displayed</li><li>Default order to display comments</li><li>Set maximum number of comments to show - default is 100</li>',
    136 => 'Exclude Topics and Authors',
    137 => 'Filter Story Content',
    138 => 'Misc Settings',
    139 => 'Layout and Language',
    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics</li><li>Set the maximum number of stories to show per page</li><li>Set your theme, timezone and preferred date format</li>',
    141 => 'Privacy Settings',
    142 => 'The default setting is to allow users & admins to email fellow site members and show your status as online. Un-check these options to protect your privacy.',
    143 => 'Filter Block Content',
    144 => 'Show & hide boxes',
    145 => 'Your Public Profile',
    146 => 'Password and email',
    147 => 'Edit your account password, email and autologin feature. You will need to enter the same password or email address twice as a confirmation.',
    148 => 'User Information',
    149 => 'Modify your user information that will be shown to other users.<li>The signature will be added to any comments or forum posts you made</li><li>The BIO is a brief summary of yourself to share</li><li>Share your PGP Key</li>',
    150 => 'Warning: Javascript recommended for enhanced functionality',
    156 => 'Delete Account',
    157 => 'Delete Option',
    158 => 'Time Zone',
    159 => 'This email was generated automatically. Please do not reply to this email.',
    160 => '(max. %d x %d pixels, %d bytes; %s)',
    161 => 'will be scaled down',
    162 => 'will not be scaled',
    163 => 'Re-Authentication Failed',
    164 => 'You have exceeded the number of allowed attempts for re-authentication. The operation has been aborted and your recent changes were lost, sorry.',
    165 => 'Use Advanced Editor'
);

###############################################################################
# Customize if need to modify the Tabbed navbar MyAccount panels used.
# Array index key matches preference div id

$LANG_MYACCOUNT = array(
    'pe_preview' => 'Preview',
    'pe_namepass' => 'Username &amp; Password',
    'pe_userinfo' => 'About You',
    'pe_layout' => 'Layout &amp; Language',
    'pe_content' => 'Content',
    'pe_privacy' => 'Privacy'
);

###############################################################################
# index.php

$LANG05 = array(
    1 => '  ',
    2 => '   .              .',
    3 => '    %s',
    4 => ' ',
    5 => '',
    6 => '',
    7 => '',
    8 => ''
);

###############################################################################
# profiles.php

$LANG08 = array(
    1 => '    ,   .',
    2 => '    .',
    3 => ',           .',
    4 => ',    ,   ,   .',
    5 => ':    .',
    6 => ' .',
    7 => '  ',
    8 => ' ',
    9 => 'URL ',
    10 => '   /',
    11 => ':',
    12 => '  :',
    13 => ':',
    14 => ':',
    15 => '  HTML  .',
    16 => ' ',
    17 => '        /',
    18 => ' ',
    19 => '  ',
    20 => ' ',
    21 => '  ',
    22 => '   ',
    23 => "       / %s    %s             {$_CONF['site_url']}.      ,             .",
    24 => '    ',
    25 => '        .          ',
    26 => '              .     .',
    27 => ' ',
    28 => ' %s : ',
    29 => "      {$_CONF['site_name']}  ",
    30 => '   ',
    31 => '',
    32 => '',
    33 => '   ',
    34 => ' ',
    35 => ',        .',
    36 => 'Copy:',
    37 => 'Send me a copy of this email',
    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:",
    39 => 'Your last message was ',
    40 => " seconds ago.  This site requires at least {$_CONF['speedlimit']} seconds between sending messages"
);

###############################################################################
# search.php

$LANG09 = array(
    1 => ' ',
    2 => ' ',
    3 => '',
    4 => '',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => '',
    10 => '',
    11 => ' ',
    12 => '',
    13 => ' :   ',
    14 => '       ',
    15 => ',  .',
    16 => '',
    17 => '',
    18 => '',
    19 => "        {$_CONF['site_name']}",
    20 => '',
    21 => '',
    22 => '(  --)',
    23 => '',
    24 => '',
    25 => ' ',
    26 => ' ',
    27 => '',
    28 => '            .',
    29 => '   ',
    30 => '',
    31 => '           . ',
    32 => '',
    33 => 'URL',
    34 => '',
    35 => '',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => '       (3) .',
    42 => ',     YYYY-MM-DD (--).',
    43 => ' ',
    44 => '  ',
    45 => '   ',
    46 => '',
    47 => '',
    48 => '',
    49 => '',
    50 => '',
    51 => '',
    52 => '',
    53 => ' ',
    54 => ' ',
    55 => ' ',
    56 => '',
    57 => '',
    58 => 'More results &gt;&gt;',
    59 => 'Results',
    60 => 'per page',
    61 => 'Refine search',
    62 => '#',
    63 => 'Description',
    64 => 'Showing %1$d - %2$d of %3$d results',
    65 => 'Story',
    66 => 'Comment',
    67 => 'Show %d Results',
    68 => 'Sort By',
    69 => 'Titles Only',
    70 => 'Not available ...',
    71 => 'asc',
    72 => 'desc'
);

###############################################################################
# stats.php

$LANG10 = array(
    1 => ' ',
    2 => '   ',
    3 => '()  ',
    4 => '',
    5 => '',
    6 => '',
    7 => ' 10   .',
    8 => ' ',
    9 => '',
    10 => '            .',
    11 => ' 10   ',
    12 => '',
    13 => '            .',
    14 => '',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => '',
    22 => ' 10        ',
    23 => ' ',
    24 => '          .',
    25 => 'Top Ten Trackback Commented Stories',
    26 => 'No trackback comments found.',
    27 => 'Number of active users',
    28 => '',
    29 => '',
    30 => 'Hits',
    31 => ''
);

###############################################################################
# article.php

$LANG11 = array(
    1 => '  ;',
    2 => '     /   ',
    3 => '   ',
    4 => '  ',
    5 => '',
    6 => 'Subscribe to \'%s\''
);

###############################################################################
# submit.php

$LANG12 = array(
    1 => '   %s     .',
    2 => '',
    3 => ' ',
    4 => '',
    5 => '',
    6 => '  ',
    7 => '   ',
    8 => '',
    9 => '      ,      ... <ul><li>   ,    <li>    <li>   URL</ul>',
    10 => '',
    11 => '',
    12 => ' ',
    13 => ' ',
    14 => '',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => ' ',
    20 => '',
    21 => '',
    22 => ':   ',
    23 => '      .    .',
    24 => '   ',
    25 => '   (%s)  ',
    26 => ' ',
    27 => ' ',
    28 => '',
    29 => '',
    30 => '     ',
    31 => "  .    {$_CONF['speedlimit']}    ",
    32 => '',
    33 => ' ',
    34 => '',
    35 => '  HTML  ',
    36 => ' ',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => '',
    42 => '',
    43 => '',
    44 => '  1',
    45 => '  2',
    46 => ' / ',
    47 => ' (   )',
    48 => ' ',
    49 => '',
    50 => '',
    51 => '',
    52 => '',
    53 => ' ',
    54 => 'Story Introduction',
    55 => 'Story Body'
);

###############################################################################
# ADMIN PHRASES - These are file phrases used in admin scripts
###############################################################################

###############################################################################
# admin/auth.inc.php

$LANG20 = array(
    1 => '   ',
    2 => '   ,      ',
    3 => '   ',
    4 => ' :',
    5 => ' :',
    6 => '            . <br' . XHTML . '>        ',
    7 => ''
);

###############################################################################
# admin/block.php

$LANG21 = array(
    1 => '   ',
    2 => '           ',
    3 => '  ',
    4 => '        (   error.log  ).',
    5 => '',
    6 => '',
    7 => '',
    8 => '   ',
    9 => '  ',
    10 => '',
    11 => ' ',
    12 => ' ',
    13 => '   ',
    14 => 'RDF URL',
    15 => '  RDF',
    16 => '  ',
    17 => ' ',
    18 => ',    ,    ',
    19 => '  ',
    20 => '',
    21 => '  ',
    22 => '',
    23 => ' ',
    24 => '',
    25 => '       ,      .           ',
    26 => ' ',
    27 => ' PHP',
    28 => '  PHP',
    29 => '  ',
    30 => '           PHP,        .          "phpblock " (   phpblock_getweather).     ,      .          ////geeklog/system/lib-custom.php.',
    31 => '   PHP.    %s,  .',
    32 => ',  ()',
    33 => '    URL   .rdf     ',
    34 => '            PHP.',
    35 => '              ',
    36 => '          ',
    37 => '    PHP  ',
    38 => '     PHP      \'phpblock_\' (  phpblock_getweather).      .',
    39 => '',
    40 => '',
    41 => '',
    42 => '              GeekLog',
    43 => '  ',
    44 => '',
    45 => "          \n   . , <a ref=\"{$_CONF['site_admin_url']}/block.php\">     </a>.",
    46 => ' ',
    47 => '',
    48 => ' ',
    49 => ' (  and      )',
    50 => 'The Block Name can not be empty',
    51 => ' http://',
    52 => '    ,         . ',
    53 => '',
    54 => '',
    55 => '',
    56 => '',
    57 => '    ',
    58 => '    ',
    59 => '    ',
    60 => '    ',
    61 => 'No Title',
    62 => 'Article Limit',
    63 => 'Bad Block Title',
    64 => 'Your Title must not be empty and cannot contain HTML!',
    65 => 'Order',
    66 => 'Autotags',
    67 => 'Check to allow autotags',
    68 => 'The feed for this portal block is too long to display. Please set a maximum number of articles to import for the block in the block setup screen, or a global maximum in Geeklog Configuration.'
);

###############################################################################
# admin/story.php

$LANG24 = array(
    1 => ' ',
    2 => ' ',
    3 => '',
    4 => '  ',
    5 => ' ',
    6 => '    ',
    7 => '',
    8 => '',
    9 => '',
    10 => '',
    11 => '',
    12 => '/',
    13 => '',
    14 => '',
    15 => '',
    16 => ' ',
    17 => ' ',
    18 => '',
    19 => '',
    20 => 'Ping',
    21 => 'Send Ping',
    22 => ' ',
    23 => '             .           ',
    24 => ' /       . ,    /.',
    25 => 'Error when saving story',
    26 => ' ',
    27 => 'If you use [unscaledX] instead of [imageX], the image will be inserted at its original dimensions.',
    28 => '<p><b>PREVIEWING</b>: Previewing a story with images attached is best done by saving the article as a draft INSTEAD OF hitting the preview button.  Use the preview button only when images are not attached.',
    29 => 'Trackbacks',
    30 => '     ',
    31 => '  ,      . ',
    32 => '',
    33 => '       .',
    34 => '',
    35 => '',
    36 => '',
    37 => '   /',
    38 => '  ',
    39 => ' ',
    40 => '',
    41 => "          .    . , <a ref=\"{$_CONF['site_admin_url']}/story.php\">     </a>.",
    42 => "          .    . , <a ref=\"{$_CONF['site_admin_url']}/story.php\">     </a>.",
    43 => '',
    44 => '',
    45 => '',
    46 => '<b>:</b>      ,          .       RDF          ',
    47 => '',
    48 => '',
    49 => '',
    50 => '',
    51 => '                  .      [imageX], [imageX_right] or [imageX_left]        . :       .    ,        . <BR><P><B></B>:                         .          ',
    52 => '',
    53 => ' .                 .',
    54 => '    ',
    55 => '          .    .',
    56 => '  ',
    57 => '   ',
    58 => ' ',
    59 => '',
    60 => '',
    61 => ' ',
    62 => ' ',
    63 => 'Disable Comments',
    64 => '',
    65 => '',
    66 => '',
    67 => 'Expand the Content Edit Area size',
    68 => 'Reduce the Content Edit Area size',
    69 => 'Publish Story Date',
    70 => 'Toolbar Selection',
    71 => 'Basic Toolbar',
    72 => 'Common Toolbar',
    73 => 'Advanced Toolbar',
    74 => 'Advanced II Toolbar',
    75 => 'Full Featured',
    76 => 'Publish Options',
    77 => 'Javascript needs to be enabled for Advanced Editor. Option can be disabled in the main site config.php',
    78 => 'Click <a href="%s/story.php?mode=edit&amp;sid=%s&amp;editopt=default">here</a> to use default editor',
    79 => 'Preview',
    80 => 'Editor',
    81 => 'Publish Options',
    82 => 'Images',
    83 => 'Archive Options',
    84 => 'Permissions',
    85 => 'Show All',
    86 => 'Advanced Editor',
    87 => 'Story Stats',
    88 => 'Wiki-style format',
    89 => 'Meta Description',
    90 => 'Meta Keywords',
    91 => 'You can always hit "Preview" to extend the expiry time.'
);

###############################################################################
# admin/topic.php

$LANG27 = array(
    1 => ' ',
    2 => '/ ',
    3 => ' ',
    4 => ' ',
    5 => '(  )',
    6 => '              . ',
    7 => '  / and     ',
    8 => ' ',
    9 => '             .           ',
    10 => ' ',
    11 => '/',
    12 => '  ',
    13 => "          .    . , <a ref=\"{$_CONF['site_admin_url']}/topic.php\">     </a>.",
    14 => ' ',
    15 => '',
    16 => '  ',
    17 => ' ',
    18 => ' ',
    19 => '',
    20 => '',
    21 => '',
    22 => '',
    23 => '       ',
    24 => '(*)',
    25 => ' ',
    26 => '      .',
    27 => 'Or Upload Topic Icon',
    28 => 'Maximum',
    29 => 'File Upload Errors',
    30 => 'Stories in Topic'
);

###############################################################################
# admin/user.php

$LANG28 = array(
    1 => ' ',
    2 => ' ',
    3 => ' ',
    4 => ' ',
    5 => ' ',
    6 => ' ',
    7 => ' ',
    8 => '',
    9 => '(  )',
    10 => '   ,  ,       ',
    11 => ' ',
    12 => '              .            .         ,        (   **  *.gr)    ',
    13 => ' ',
    14 => ' .',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => '    ',
    22 => '',
    23 => ' ',
    24 => '  ',
    25 => "       Geeklog.         :  ,  ,  .              .        . \n ,    ,        .",
    26 => '',
    27 => '',
    28 => '     ',
    29 => '',
    30 => '',
    31 => ' ',
    32 => '  .  %d  %d ',
    33 => '',
    34 => ':       .',
    35 => '   ',
    36 => '()',
    37 => 'UID',
    38 => 'Group Listing',
    39 => 'Password (again)',
    40 => 'Registration Date',
    41 => 'Last login Date',
    42 => 'Banned',
    43 => 'Awaiting Activation',
    44 => 'Awaiting Authorization',
    45 => 'Active',
    46 => 'User Status',
    47 => 'Edit',
    48 => 'Show Admin Groups',
    49 => 'Admin Group',
    50 => 'Check to allow filtering this group as an Admin Use Group',
    51 => 'Online Days',
    52 => '<br' . XHTML . '>Note: "Online Days" is the number of days between the first registration and the last login.',
    53 => 'registered',
    54 => 'Batch Delete',
    55 => 'This only works if you have <code>$_CONF[\'lastlogin\'] = true;</code> in your config.php',
    56 => 'Please choose the type of user you want to delete and press "Update List". Then, uncheck those from the list you do not want to delete and press "Delete". Please note that you will only delete those that are currently visible in case the list spans over several pages.',
    57 => 'Phantom users',
    58 => 'Short-Time Users',
    59 => 'Old Users',
    60 => 'Users that registered more than ',
    61 => ' months ago, but never logged in.',
    62 => 'Users that registered more than ',
    63 => ' months ago, then logged in within 24 hours, but since then never came back to your site.',
    64 => 'Normal users, who simply did not visit your site since ',
    65 => ' months.',
    66 => 'Update List',
    67 => 'Months since registration',
    68 => 'Online Hours',
    69 => 'Offline Months',
    70 => 'could not be deleted',
    71 => 'sucessfully deleted',
    72 => 'No User selected for deletion',
    73 => 'Are You sure you want to permanently delete ALL selected users?',
    74 => 'Recent Users',
    75 => 'Users that registered in the last ',
    76 => ' months',
    77 => 'Email site login reminder to selected users',
    78 => 'Send Reminder',
    79 => 'No User selected for reminders',
    80 => 'Successfully sent Reminders',
    81 => 'Reminder to verify account for %s',
    82 => "Your account on {$_CONF['site_name']} has not been accesssed since %s and will be disabled if not accessed in the 30 days.",
    83 => "Your account on {$_CONF['site_name']} has not been used since it was created and will deleted soon if not accessed.",
    84 => "Your login name is: %s  for our site: {$_CONF['site_url']}",
    85 => 'If you have forgotten the password use the following link: %s',
    86 => 'Include',
    87 => 'Reminders',
    88 => 'Default Group',
    89 => 'Check to make this a default group for new users',
    90 => 'Apply "Default Group" change to existing user accounts'
);

###############################################################################
# admin/moderation.php

$LANG29 = array(
    1 => '',
    2 => '',
    3 => '',
    4 => '',
    10 => '',
    11 => ' ',
    12 => 'URL',
    13 => '',
    14 => '',
    15 => '',
    16 => ' ',
    17 => ' ',
    18 => ' ',
    34 => '  ',
    35 => ' ',
    36 => 'Parent or Comment',
    37 => '',
    38 => '',
    39 => '       ',
    40 => ' ',
    41 => 'Comment Submissions',
    42 => 'Username',
    43 => 'Auto-publish Comments?'
);

###############################################################################
# admin/mail.php

$LANG31 = array(
    1 => "{$_CONF['site_name']}   ",
    2 => '',
    3 => '-',
    4 => '',
    5 => '',
    6 => ':',
    7 => '  ',
    8 => '',
    9 => '',
    10 => 'HTML',
    11 => ' !',
    12 => '',
    13 => '  ',
    14 => '  ',
    15 => '    : ',
    16 => '  : ',
    17 => "<a href={$_CONF['site_admin_url']}/mail.php>  </a>",
    18 => '',
    19 => ':                       ',
    20 => "  <successcount>      <failcount> .   ,        . ,   <a href=\"{$_CONF['site_admin_url']}/mail.php\">  </a>    <a href=\"{$_CONF['site_admin_url']}/moderation.php\">   </a>.",
    21 => '',
    22 => '',
    23 => ' ',
    24 => ' ',
    25 => '--   --',
    26 => ',    .    .'
);

###############################################################################
# admin/plugins.php

$LANG32 = array(
    1 => '             Geeklog     .             <a href="http://www.geeklog.net" target="_blank">Geeklog Homepage</a>         .                                   .                           .      .             . ',
    2 => '    ',
    3 => '   ',
    4 => '  ',
    5 => '  ',
    6 => ':      ',
    7 => '         . ,    .',
    8 => 'H      ',
    9 => '        Geeklog.       <a href="http://www.geeklog.net">Geeklog</a>      .',
    10 => '<br' . XHTML . '><b>    .</b><br' . XHTML . '><br' . XHTML . '>',
    11 => '        ,        .         ,          .   to      . ',
    12 => '      a  plugineditor()',
    13 => '  ',
    14 => '  ',
    15 => ' ',
    16 => '  ',
    17 => '  ',
    18 => ' Geeklog',
    19 => '',
    20 => '',
    21 => '',
    22 => '',
    23 => '',
    24 => '',
    25 => '',
    26 => '  ',
    27 => '  ',
    28 => '  ',
    29 => ' Geeklog',
    30 => '  ;',
    31 => ' /        ;      ,           .   /        .',
    32 => '<p><b>,    "AutoLink tag"   </b></p>',
    33 => ' ',
    34 => '',
    35 => 'Edit',
    36 => 'Code',
    37 => 'Data',
    38 => 'Update!',
    39 => 'Upload a plugin',
    40 => 'You can upload a plugin archive (.tar.gz, .tgz, .zip) directly here:',
    41 => 'Upload',
    42 => 'Click to update',
    99 => 'An unknown error occured',
    100 => 'Ok.',
    101 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
    102 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
    103 => 'The uploaded file was only partially uploaded.',
    104 => 'No file was uploaded.',
    105 => '(undefined error)',
    106 => 'Missing a temporary folder.',
    107 => 'Failed to write file to disk.',
    108 => 'File upload stopped by extension.'
);

###############################################################################
# admin/syndication.php

$LANG33 = array(
    1 => '  ',
    2 => '',
    3 => '',
    4 => '',
    10 => ' ',
    11 => '  ',
    12 => ' ',
    13 => '           .           .',
    14 => '',
    15 => '',
    16 => ' ',
    17 => '',
    18 => ' ',
    19 => '',
    20 => '',
    21 => '',
    22 => '<i>(   )</i>',
    23 => '  ',
    24 => '  ',
    25 => '  ',
    26 => '',
    27 => ' ',
    28 => '(0 =  , 1 =  ,  =     .)',
    29 => '',
    30 => ' ',
    31 => ' ',
    32 => '',
    33 => '',
    34 => '',
    35 => '',
    36 => '  ',
    37 => '',
    38 => ':     ',
    39 => ',     ,    .',
    40 => ',          .',
    41 => '',
    42 => '',
    43 => 'All',
    44 => 'None',
    45 => 'Header-link in topic',
    46 => 'Limit Results',
    47 => 'Search',
    48 => 'Edit',
    49 => 'Feed Logo',
    50 => "Relative to site url ({$_CONF['site_url']})",
    51 => 'The filename you have chosen is already used by another feed. Please choose a different one.',
    52 => 'Error: existing Filename',
    53 => 'All Frontpage Stories',
    54 => 'Please select the type of feed to create.',
    55 => 'Articles'
);

###############################################################################
# confirmation and error messages

$MESSAGE = array(
    1 => "         . ,        {$_CONF['site_name']}",
    2 => "        {$_CONF['site_name']}.             .           ",
    3 => '',
    4 => '',
    5 => '      .',
    6 => '     .',
    7 => '     .',
    8 => '  .',
    9 => '    .',
    10 => '   .',
    11 => '    .',
    12 => '   .',
    13 => '    .',
    14 => '          .',
    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => '    .',
    22 => '   .',
    23 => '',
    24 => '',
    25 => '',
    26 => '',
    27 => '   .',
    28 => '    ',
    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
    30 => '  ',
    31 => '',
    32 => '',
    33 => '',
    34 => '',
    35 => '',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => ' ',
    41 => '',
    42 => '',
    43 => '',
    44 => '     !',
    45 => '     !',
    46 => '',
    47 => '',
    48 => "          {$_CONF['site_name']}.        .               .",
    49 => '    .',
    50 => '   .',
    51 => '            . ,    .',
    52 => '       .',
    53 => '      . ,         .',
    54 => '          . ,  .',
    55 => '          . ,                .',
    56 => '               .',
    57 => '    ',
    58 => '    ',
    59 => '    ',
    60 => '    ',
    61 => '  %s: o  ',
    62 => 'The trackback comment has been deleted.',
    63 => 'An error occurred when deleting the trackback comment.',
    64 => 'Your trackback comment has been successfully sent.',
    65 => 'Weblog directory service successfully saved.',
    66 => 'The weblog directory service has been deleted.',
    67 => 'The new password does not match the confirmation password!',
    68 => 'You have to enter the correct current password.',
    69 => 'Your account has been blocked!',
    70 => 'Your account is awaiting administrator approval.',
    71 => 'Your account has now been confirmed and is awaiting administrator approval.',
    72 => 'An error occured while attempting to install the plugin. See error.log for details.',
    73 => 'An error occured while attempting to uninstall the plugin. See error.log for details.',
    74 => 'The pingback has been successfully sent.',
    75 => 'Trackbacks must be sent using a POST request.',
    76 => 'Do you really want to delete this item?',
    77 => 'WARNING:<br' . XHTML . '>You have set your default encoding to UTF-8. However, your server does not support multibyte encodings. Please install mbstring functions for PHP or choose a different character set/language.',
    78 => 'Please make sure that the email address and the confirmation email address are the same.',
    79 => 'The page you have been trying to open refers to a function that no longer exists on this site.',
    80 => 'The plugin that created this feed is currently disabled. You will not be able to edit this feed until you re-enable the parent plugin.',
    81 => 'You may have mistyped your login credentials.  Please try logging in again below.',
    82 => 'You have exceeded the number of allowed login attempts.  Please try again later.',
    83 => 'To change your password, email address, or for how long to remember you, please enter your current password.',
    84 => 'To delete your account, please enter your current password.',
    85 => 'There was a problem sending the email.',
    86 => 'The OpenID server invalidated your login attempt.',
    87 => 'OpenID login operation cancelled by user.',
    88 => 'The OpenID server returned an error.',
    89 => 'Unable to find an OpenID server for the given identity URL.',
    90 => 'OpenID identification cancelled.',
    91 => 'You specified an invalid identity URL.',
    92 => "Please <a href=\"{$_CONF['site_admin_url']}/sectest.php\">check the security of your site</a> before using it!",
    93 => 'Database back up was successful.',
    94 => 'Backup Failed: Filesize less than 1kb',
    95 => 'There was an error.',
    96 => '',
    97 => '',
    98 => 'The plugin was successfully uploaded.',
    99 => 'The plugin already exists.',
    100 => 'The plugin file you uploaded was not a GZip or Zip compressed archive.',
    101 => 'There are no topics (that you have access to). You need at least one topic to be able to submit stories.',
    400 => 'Not all required fields have been passed validation',
    401 => 'Please enter Fullname'
);

###############################################################################

$LANG_ACCESS = array(
    'access' => '',
    'ownerroot' => '/Root',
    'group' => '',
    'readonly' => ' ',
    'accessrights' => ' ',
    'owner' => '',
    'grantgrouplabel' => '    ',
    'permmsg' => ':               .',
    'securitygroups' => ' ',
    'editrootmsg' => "     ,                .            .            .     <a href=\"{$_CONF['site_admin_url']}/user.php\"> </a>.",
    'securitygroupsmsg' => '           . ',
    'groupeditor' => ' ',
    'description' => '',
    'name' => '',
    'rights' => '',
    'missingfields' => ' ',
    'missingfieldsmsg' => '       ',
    'groupmanager' => ' ',
    'newgroupmsg' => '           .          .       .',
    'groupname' => ' ',
    'coregroup' => ' ',
    'yes' => '',
    'no' => '',
    'corerightsdescr' => "       {$_CONF['site_name']}.           .       -       .",
    'groupmsg' => '        .                       .   ,       .               .                   .',
    'coregroupmsg' => "  {$_CONF['site_name']}  .             .       -      .",
    'rightsdescr' => '                       .                         .              ',
    'lock' => '',
    'members' => '',
    'anonymous' => '',
    'permissions' => '',
    'permissionskey' => 'R = , E = ,      ',
    'edit' => '',
    'none' => '',
    'accessdenied' => '  ',
    'storydenialmsg' => "       .         {$_CONF['site_name']}.    <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">   </a> of {$_CONF['site_name']}       !",
    'nogroupsforcoregroup' => '          ',
    'grouphasnorights' => '              ',
    'newgroup' => ' ',
    'adminhome' => ' ',
    'save' => '',
    'cancel' => '',
    'delete' => '',
    'canteditroot' => '                 .               .',
    'listusers' => ' ',
    'listthem' => '',
    'usersingroup' => '    "%s"',
    'usergroupadmin' => '  ',
    'add' => '',
    'remove' => '',
    'availmembers' => ' ',
    'groupmembers' => ' ',
    'canteditgroup' => '          .             .',
    'cantlistgroup' => '              .             .',
    'editgroupmsg' => 'To modify the group membership, click on the member names(s) and use the add or remove buttons. If the member is a member of the group, their name will appear on the right side only. Once you are complete - press <b>Save</b> to update the group and return to the main group admin page.',
    'listgroupmsg' => 'Listing of all current members in the group: <b>%s</b>',
    'search' => 'Search',
    'submit' => 'Submit',
    'limitresults' => 'Limit Results',
    'group_id' => 'Group ID',
    'plugin_access_denied_msg' => 'You are illegally trying access a plugin administration page.  Please note that all attempts to illegally access this page are logged.',
    'groupexists' => 'Group name already exists',
    'groupexistsmsg' => 'There is already a group with this name. Group names must be unique.'
);

###############################################################################
# admin/database.php

$LANG_DB_BACKUP = array(
    'last_ten_backups' => ' 10  ',
    'do_backup' => '  ',
    'backup_successful' => '       ',
    'db_explanation' => '         Geeklog,    ',
    'not_found' => "     mysqldump   . <br" . XHTML . ">Check <strong>\$_DB_mysqldump_path</strong> definition in config.php.<br" . XHTML . ">   : <var>{$_DB_mysqldump_path}</var>",
    'zero_size' => '   :      0 bytes',
    'path_not_found' => "{$_CONF['backup_path']}      ",
    'no_access' => ":   {$_CONF['backup_path']}   .",
    'backup_file' => '  ',
    'size' => '',
    'bytes' => 'ytes',
    'total_number' => '   : %d',
    'download' => 'Click to download this file',
    'new_backup' => 'New Backup',
    'delete_failure' => 'One or more backup files could not be deleted.',
    'delete_success' => 'Backup file(s) successfully deleted.',
    'convert_menu' => 'Convert to InnoDB',
    'convert_title' => 'Convert to InnoDB tables',
    'convert_button' => 'Convert',
    'sorry_no_innodb' => 'Sorry, your version of MySQL does not support InnoDB tables.',
    'innodb_explain' => 'InnoDB tables provide better performance on <em>really</em> large databases but make the backup process more complicated. Please <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">read up</a> on the pros and cons of InnoDB tables before you perform this operation.',
    'already_converted' => 'Note: It appears that all of the tables have already been converted to InnoDB.',
    'conversion_patience' => 'Note: Conversion may take some time - please be patient.',
    'innodb_success' => 'Successfully converted tables to InnoDB.',
    'table_issues' => 'There may have been problems with some tables, though. Please check error.log for details.',
    'optimize_menu' => 'Optimize Tables',
    'optimize_title' => 'Optimize Tables',
    'optimize_button' => 'Optimize',
    'optimize_explain' => 'Optimizing tables may help to improve the performance of your site. The actual impact depends on the table usage and some tables may benefit from it more than others. Do no expect to see a huge difference in performance. The <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manual</a> states: <q>it is not likely that you need to do this more than once a week or month</q>.',
    'last_optimization' => 'Last optimization',
    'optimization_patience' => 'Note: Optimization may take some time - please be patient.',
    'optimize_success' => 'Successfully optimized database tables.'
);

###############################################################################

$LANG_BUTTONS = array(
    1 => ' ',
    2 => '',
    3 => ' ',
    4 => '',
    5 => '',
    6 => '',
    7 => ' ',
    8 => '',
    9 => '',
    10 => ' ',
    11 => 'Directory'
);

###############################################################################
# 404.php

$LANG_404 = array(
    1 => '404 Error',
    2 => '           <b>%s</b>.',
    3 => "<p>,        .     <a href=\"{$_CONF['site_url']}\"> </a> or the <a href=\"{$_CONF['site_url']}/search.php\"> </a>        , ."
);

###############################################################################
# login form

$LANG_LOGIN = array(
    1 => '    ',
    2 => '          .',
    3 => '',
    4 => '  '
);

###############################################################################
# trackback.php

$LANG_TRB = array(
    'trackback' => 'Trackback',
    'from' => 'from',
    'tracked_on' => 'Tracked on',
    'read_more' => '[read more]',
    'intro_text' => 'Here\'s what others have to say about \'%s\':',
    'no_comments' => 'No trackback comments for this entry.',
    'this_trackback_url' => 'Trackback URL for this entry:',
    'num_comments' => '%d trackback comments',
    'send_trackback' => 'Send Pings',
    'preview' => 'Preview',
    'editor_title' => 'Send trackback comment',
    'trackback_url' => 'Trackback URL',
    'entry_url' => 'Entry URL',
    'entry_title' => 'Entry Title',
    'blog_name' => 'Site Name',
    'excerpt' => 'Excerpt',
    'truncate_warning' => 'Note: The receiving site may truncate your excerpt',
    'button_send' => 'Send',
    'button_preview' => 'Preview',
    'send_error' => 'Error',
    'send_error_details' => 'Error when sending trackback comment:',
    'url_missing' => 'No Entry URL',
    'url_required' => 'Please enter at least a URL for the entry.',
    'target_missing' => 'No Trackback URL',
    'target_required' => 'Please enter a trackback URL',
    'error_socket' => 'Could not open socket.',
    'error_response' => 'Response not understood.',
    'error_unspecified' => 'Unspecified error.',
    'select_url' => 'Select Trackback URL',
    'not_found' => 'Trackback URL not found',
    'autodetect_failed' => 'Geeklog could not detect the Trackback URL for the post you want to send your comment to. Please enter it manually below.',
    'trackback_explain' => 'From the links below, please select the URL you want to send your Trackback comment to. Geeklog will then try to determine the correct Trackback URL for that post. Or you can <a href="%s">enter it manually</a> if you know it already.',
    'no_links_trackback' => 'No links found. You can not send a Trackback comment for this entry.',
    'pingback' => 'Pingback',
    'pingback_results' => 'Pingback results',
    'send_pings' => 'Send Pings',
    'send_pings_for' => 'Send Pings for "%s"',
    'no_links_pingback' => 'No links found. No Pingbacks were sent for this entry.',
    'pingback_success' => 'Pingback sent.',
    'no_pingback_url' => 'No pingback URL found.',
    'resend' => 'Resend',
    'ping_all_explain' => 'You can now notify the sites you linked to (<a href="http://en.wikipedia.org/wiki/Pingback">Pingback</a>), advertise that your site has been updated by pinging weblog directory services, or send a <a href="http://en.wikipedia.org/wiki/Trackback">Trackback</a> comment in case you wrote about a post on someone else\'s site.',
    'pingback_button' => 'Send Pingback',
    'pingback_short' => 'Send Pingbacks to all sites linked from this entry.',
    'pingback_disabled' => '(Pingback disabled)',
    'ping_button' => 'Send Ping',
    'ping_short' => 'Ping weblog directory services.',
    'ping_disabled' => '(Ping disabled)',
    'trackback_button' => 'Send Trackback',
    'trackback_short' => 'Send a Trackback comment.',
    'trackback_disabled' => '(Trackback disabled)',
    'may_take_a_while' => 'Please note that sending Pingbacks and Pings may take a while.',
    'ping_results' => 'Ping results',
    'unknown_method' => 'Unknown ping method',
    'ping_success' => 'Ping sent.',
    'error_site_name' => 'Please enter the site\'s name.',
    'error_site_url' => 'Please enter the site\'s URL.',
    'error_ping_url' => 'Please enter a valid Ping URL.',
    'no_services' => 'No weblog directory services configured.',
    'services_headline' => 'Weblog Directory Services',
    'service_explain' => 'To modify or delete a weblog directory service, click on the edit icon of that service below. To add a new weblog directory service, click on "Create New" above.',
    'service' => 'Service',
    'ping_method' => 'Ping method',
    'service_website' => 'Website',
    'service_ping_url' => 'URL to ping',
    'ping_standard' => 'Standard Ping',
    'ping_extended' => 'Extended Ping',
    'ping_unknown' => '(unknown method)',
    'edit_service' => 'Edit Weblog Directory Service',
    'trackbacks' => 'Trackbacks',
    'editor_intro' => 'Prepare your trackback comment for <a href="%s">%s</a>.',
    'editor_intro_none' => 'Prepare your trackback comment.',
    'trackback_note' => 'To send a trackback comment for a story, go to the list of stories and click on "Send Ping" for the story. To send a trackback that is not related to a story, <a href="%s">click here</a>.',
    'pingback_explain' => 'Enter a URL to send the Pingback to. The pingback will point to your site\'s homepage.',
    'pingback_url' => 'Pingback URL',
    'site_url' => 'This site\'s URL',
    'pingback_note' => 'To send a pingback for a story, go to the list of stories and click on "Send Ping" for the story. To send a pingback that is not related to a story, <a href="%s">click here</a>.',
    'pbtarget_missing' => 'No Pingback URL',
    'pbtarget_required' => 'Please enter a pingback URL',
    'pb_error_details' => 'Error when sending the pingback:',
    'delete_trackback' => 'To delete this Trackback click: '
);

###############################################################################
# directory.php

$LANG_DIR = array(
    'title' => 'Article Directory',
    'title_year' => 'Article Directory for %d',
    'title_month_year' => 'Article Directory for %s %d',
    'nav_top' => 'Back to Article Directory',
    'no_articles' => 'No articles.'
);

###############################################################################
# admin/sectest.php

$LANG_SECTEST = array(
    'sectest' => 'Geeklog Security Check',
    'results' => 'Results of the Security Check',
    'okay' => 'Everything seems to be in order.',
    'please_fix' => 'Please fix the above issues before using your site!',
    'please_note' => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
    'stay_informed' => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) %s mailing list and/or use the %s option in your Admin menu from time to time to check for available updates.',
    'public_html' => '"public_html" should never be part of your site\'s URL.  Please read the part about public_html in the %s again and change your setup accordingly before you proceed.',
    'installation' => 'installation instructions',
    'directory' => 'directory',
    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
    'fix_it' => 'This is a security risk and should be fixed!',
    'reachable' => 'Your %s is reachable from the web.',
    'not_reachable' => 'Good! Your %s is not reachable from the web.',
    'not_sure' => 'Got an HTTP result code %s when trying to test your %s. Not sure what to make of it ...',
    'remove_inst' => 'You should really remove the install directory %s once you have your site up and running without any errors.',
    'remove_inst2' => 'Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
    'inst_removed' => 'Good! You seem to have removed the install directory already.',
    'fix_password' => 'You still have not changed the <strong>default password</strong> from "password" on %s Root user account(s).',
    'password_okay' => 'Good! You seem to have changed the default account password already.'
);

###############################################################################
# "What's New" Time Strings
# 
# For the first two strings, you can use the following placeholders.
# Order them so it makes sense in your language:
# %i    item, "Stories"
# %n    amount, "2", "20" etc.
# %t    time, "2" (weeks)
# %s    scale, "hrs", "weeks"

$LANG_WHATSNEW = array(
    'new_string' => '%n new %i in the last %t %s',
    'new_last' => 'last %t %s',
    'minutes' => 'minutes',
    'hours' => 'hours',
    'days' => 'days',
    'weeks' => 'weeks',
    'months' => 'months',
    'years' => 'years',
    'minute' => 'minute',
    'hour' => 'hour',
    'day' => 'day',
    'week' => 'week',
    'month' => 'month',
    'year' => 'year'
);

###############################################################################
# Month names

$LANG_MONTH = array(
    1 => '',
    2 => '',
    3 => '',
    4 => '',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => '',
    10 => '',
    11 => '',
    12 => ''
);

###############################################################################
# Weekdays

$LANG_WEEK = array(
    1 => '',
    2 => '',
    3 => '',
    4 => '',
    5 => '',
    6 => '',
    7 => ''
);

###############################################################################
# Admin - Strings
# 
# These are some standard strings used by core functions as well as plugins to
# display administration lists and edit pages

$LANG_ADMIN = array(
    'search' => 'Search',
    'limit_results' => 'Limit Results',
    'submit' => 'Submit',
    'edit' => 'Edit',
    'edit_adv' => 'Adv. Edit',
    'admin_home' => 'Admin Home',
    'create_new' => 'Create New',
    'create_new_adv' => 'Create New (Adv.)',
    'enabled' => 'Enabled',
    'title' => 'Title',
    'page_title' => 'Page Title',
    'type' => 'Type',
    'topic' => 'Topic',
    'help_url' => 'Help File URL',
    'save' => 'Save',
    'cancel' => 'Cancel',
    'delete' => 'Delete',
    'delete_sel' => 'Delete selected',
    'copy' => 'Copy',
    'no_results' => '- No entries found -',
    'data_error' => 'There was an error processing the subscription data. Please check the data source.',
    'preview' => 'Preview',
    'records_found' => 'Records found',
    'addchild' => 'Add child',
    'list' => 'list',
    'list_all' => 'List all',
    'meta_description' => 'Meta Description',
    'meta_keywords' => 'Meta Keywords',
    'na' => 'N/A',
    'token_expiry' => 'You have until %s to make changes. After that time, the security token embedded into this page will expire and you will lose your changes.',
    'token_expired' => 'The security token for this operation has expired. Please authenticate again to continue.',
    'reauth_msg' => 'The security token for this operation has expired. If you want to continue with this operation, then please authenticate again below. This will ensure that the changes you just made will not be lost.',
    'authenticate' => 'Authenticate'
);

# Localisation of the texts for the various drop-down menus that are actually
# stored in the database. If these exist, they override the texts from the
# database.

$LANG_commentcodes = array(
    0 => 'Comments Enabled',
    -1 => 'Comments Disabled',
    1 => 'Comments Closed'
);

$LANG_commentmodes = array(
    'flat' => 'Flat',
    'nested' => 'Nested',
    'threaded' => 'Threaded',
    'nocomment' => 'No Comments'
);

$LANG_cookiecodes = array(
    0 => '(don\'t)',
    3600 => '1 Hour',
    7200 => '2 Hours',
    10800 => '3 Hours',
    28800 => '8 Hours',
    86400 => '1 Day',
    604800 => '1 Week',
    2678400 => '1 Month'
);

$LANG_dateformats = array(
    0 => 'System Default'
);

$LANG_featurecodes = array(
    0 => 'Not Featured',
    1 => 'Featured'
);

$LANG_frontpagecodes = array(
    0 => 'Show Only in Topic',
    1 => 'Show on Front Page'
);

$LANG_postmodes = array(
    'plaintext' => 'Plain Old Text',
    'html' => 'HTML Formatted'
);

$LANG_sortcodes = array(
    'ASC' => 'Oldest First',
    'DESC' => 'Newest First'
);

$LANG_trackbackcodes = array(
    0 => 'Trackback Enabled',
    -1 => 'Trackback Disabled'
);

###############################################################################
# Localization of the Admin Configuration UI

$LANG_CONFIG = array(
    'home' => 'Home',
    'admin_home' => 'Site Administration',
    'sections' => 'Configuration Sections',
    'restore' => 'Restore',
    'add_element' => 'Add Element',
    'save_changes' => 'Save Changes',
    'reset_form' => 'Reset Form',
    'changes_made' => 'Changes were successfully made to',
    'title' => 'Configuration Manager',
    'disable' => 'Click to disable this option',
    'enable' => 'Enable'
);

$LANG_configsections['Core'] = array(
    'label' => 'Geeklog',
    'title' => 'Geeklog Configuration'
);

$LANG_confignames['Core'] = array(
    'path_html' => 'HTML Path',
    'site_url' => 'Site URL',
    'site_admin_url' => 'Admin URL',
    'site_mail' => 'Site E-Mail',
    'noreply_mail' => 'No-Reply E-Mail',
    'site_name' => 'Site Name',
    'site_slogan' => 'Slogan',
    'microsummary_short' => 'Microsummary',
    'path_log' => 'Log',
    'path_language' => 'Language',
    'backup_path' => 'Backup',
    'path_data' => 'Data',
    'path_images' => 'Images',
    'path_pear' => 'Path Pear',
    'have_pear' => 'Have Pear?',
    'mail_settings' => 'Mail Settings',
    'allow_mysqldump' => 'Allow MySQL Dump',
    'mysqldump_path' => 'Path of Executable',
    'mysqldump_options' => 'MySQL Dump Options',
    'mysqldump_filename_mask' => 'Backup File Name Mask',
    'theme' => 'Theme',
    'doctype' => 'DOCTYPE Declaration',
    'menu_elements' => 'Menu Elements',
    'path_themes' => 'Themes Path',
    'disable_new_user_registration' => 'Disable New Registrations',
    'allow_user_themes' => 'Allow User Themes',
    'allow_user_language' => 'Allow User Language',
    'allow_user_photo' => 'Allow User Photo',
    'allow_username_change' => 'Allow Username Changes',
    'allow_account_delete' => 'Allow Account Deletion',
    'hide_author_exclusion' => 'Allow Hide Author',
    'show_fullname' => 'Show Fullname',
    'show_servicename' => 'Show Service Name',
    'custom_registration' => 'Enable Custom Registration',
    'user_login_method' => 'User Login Method',
    'spamx' => 'Spam-X Actions',
    'sort_admin' => 'Sort Links',
    'language' => 'Language',
    'locale' => 'Locale',
    'date' => 'Date Format',
    'daytime' => 'Daytime Format',
    'shortdate' => 'Short Date Format',
    'dateonly' => 'Date Only Format',
    'timeonly' => 'Time Only Format',
    'week_start' => 'Week Start',
    'hour_mode' => 'Hour Mode',
    'thousand_separator' => 'Thousands Separator',
    'decimal_separator' => 'Decimal Separator',
    'decimal_count' => 'Decimal Count',
    'language_files' => 'Language Files',
    'languages' => 'Languages',
    'timezone' => 'Timezone',
    'site_disabled_msg' => 'Site Disabled Message or URL',
    'rootdebug' => 'Root Debugging',
    'cookie_session' => 'Session Cookie Name',
    'cookie_name' => 'Permanent Cookie Name',
    'cookie_password' => 'Password Cookie Name',
    'cookie_theme' => 'Theme Cookie Name',
    'cookie_language' => 'Language Cookie Name',
    'cookie_tzid' => 'Timezone Cookie Name',
    'cookie_anon_name' => 'Anon. Username Cookie Name',
    'cookie_ip' => 'Cookies embed IP?',
    'default_perm_cookie_timeout' => 'Permanent Timeout',
    'session_cookie_timeout' => 'Session Timeout',
    'cookie_path' => 'Cookie Path',
    'cookiedomain' => 'Cookie Domain',
    'cookiesecure' => 'Cookie Secure',
    'lastlogin' => 'Record Last Login?',
    'num_search_results' => 'Number of Search Results',
    'loginrequired' => 'Login Required?',
    'submitloginrequired' => 'Submit Login Required?',
    'commentsloginrequired' => 'Comment Login Required?',
    'statsloginrequired' => 'Stats Login Required?',
    'searchloginrequired' => 'Search Login Required?',
    'profileloginrequired' => 'Profile Login Required?',
    'emailuserloginrequired' => 'E-Mail User Login Required?',
    'emailstoryloginrequired' => 'E-Mail Story Login Required?',
    'directoryloginrequired' => 'Directory Login Required?',
    'storysubmission' => 'Story Submission Queue?',
    'usersubmission' => 'User Submission Queue?',
    'listdraftstories' => 'List Draft Stories?',
    'notification' => 'Notifications',
    'postmode' => 'Default Post Mode',
    'speedlimit' => 'Post Speed Limit',
    'skip_preview' => 'Skip Preview in Posts',
    'advanced_editor' => 'Advanced Editor?',
    'wikitext_editor' => 'Wikitext Editor?',
    'cron_schedule_interval' => 'Cron Schedule Interval',
    'sortmethod' => 'Sort Topics',
    'showstorycount' => 'Show Story Count?',
    'showsubmissioncount' => 'Show Submission Count?',
    'hide_home_link' => 'Hide Home Link?',
    'whosonline_threshold' => 'Session Threshold',
    'whosonline_anonymous' => 'Hide Names from Guests?',
    'emailstories' => 'Daily Digest Enabled?',
    'emailstorieslength' => 'Length of Stories',
    'emailstoriesperdefault' => 'Enable for New Users?',
    'allow_domains' => 'Automatic Allow Domains',
    'disallow_domains' => 'Automatic Disallow Domains',
    'newstoriesinterval' => 'New Stories Interval',
    'newcommentsinterval' => 'New Comments Interval',
    'newtrackbackinterval' => 'New Trackbacks Interval',
    'hidenewstories' => 'Hide New Stories',
    'hidenewcomments' => 'Hide New Comments',
    'hidenewtrackbacks' => 'Hide New Trackbacks',
    'hidenewplugins' => 'Hide New Plugin Entries',
    'title_trim_length' => 'Title Trim Length',
    'trackback_enabled' => 'Trackback Enabled?',
    'pingback_enabled' => 'Pingback Enabled?',
    'ping_enabled' => 'Ping Enabled?',
    'trackback_code' => 'Trackback Default',
    'multiple_trackbacks' => 'Multiple Trackbacks',
    'trackbackspeedlimit' => 'Trackback Speed Limit',
    'check_trackback_link' => 'Check Trackbacks',
    'pingback_self' => 'Pingback Self?',
    'pingback_excerpt' => 'Create Pingback Excerpt?',
    'link_documentation' => 'Link to Documentation?',
    'link_versionchecker' => 'Link to Version Checker?',
    'maximagesperarticle' => 'Max Images per Article',
    'limitnews' => 'Stories per Page',
    'minnews' => 'Min. Stories per Page',
    'contributedbyline' => 'Show "Contributed By"?"',
    'hideviewscount' => 'Hide Views Count?',
    'hideemailicon' => 'Hide E-Mail Icon?',
    'hideprintericon' => 'Hide Print Icon?',
    'allow_page_breaks' => 'Allow Page Breaks?',
    'page_break_comments' => 'Comments on Multi-Page Articles',
    'article_image_align' => 'Topic Icon Alignment',
    'show_topic_icon' => 'Show Topic Icon?',
    'draft_flag' => 'Draft Flag Default',
    'frontpage' => 'Frontpage Default',
    'hide_no_news_msg' => 'Hide "No News" Message?',
    'hide_main_page_navigation' => 'Hide Main Page Navigation?',
    'onlyrootfeatures' => 'Only Root can Feature?',
    'aftersave_story' => 'After Saving Story',
    'aftersave_user' => 'After Saving User',
    'show_right_blocks' => 'Always Show Right Blocks?',
    'showfirstasfeatured' => 'Show First Story as Featured?',
    'backend' => 'Enable Feeds?',
    'rdf_file' => 'Syndication Output Folder',
    'rdf_limit' => 'Feed Limit',
    'rdf_storytext' => 'Length of Stories in Feed',
    'rdf_language' => 'Feed Language',
    'syndication_max_headlines' => 'Max. Number of Headlines (portal blocks)',
    'copyrightyear' => 'Copyright Year',
    'image_lib' => 'Image Library',
    'path_to_mogrify' => 'Path to Mogrify',
    'path_to_netpbm' => 'Path to Netpbm',
    'debug_image_upload' => 'Debug Image Uploading?',
    'keep_unscaled_image' => 'Keep Unscaled Image?',
    'allow_user_scaling' => 'Allow User Scaling?',
    'jpeg_quality' => 'JPEG Quality?',
    'max_image_width' => 'Max Image Width?',
    'max_image_height' => 'Max Image Height?',
    'max_image_size' => 'Max Image Size?',
    'max_topicicon_width' => 'Max Topic Icon Width?',
    'max_topicicon_height' => 'Max Topic Icon Height?',
    'max_topicicon_size' => 'Max Topic Icon Size?',
    'max_photo_width' => 'Max Photo Width?',
    'max_photo_height' => 'Max Photo Height?',
    'max_photo_size' => 'Max Photo Size?',
    'use_gravatar' => 'Use Gravatar?',
    'gravatar_rating' => 'Gravatar Rating',
    'force_photo_width' => 'Force Photo Width',
    'default_photo' => 'Default Photo',
    'commentspeedlimit' => 'Comment Speed Limit',
    'comment_limit' => 'Comment Limit',
    'comment_mode' => 'Comment Mode',
    'comment_code' => 'Comment Default',
    'comment_edit' => 'Allow Comment Edit?',
    'comment_edittime' => 'Comment Edit Time (seconds)',
    'commentsubmission' => 'Queue Comment Submissions',
    'passwordspeedlimit' => 'Password Speed Limit',
    'login_attempts' => 'Max. Login Attempts',
    'login_speedlimit' => 'Login Speed Limit',
    'user_html' => 'User HTML',
    'admin_html' => 'Admin HTML',
    'advanced_html' => 'Additional HTML for Adv. Editor',
    'skip_html_filter_for_root' => 'Skip HTML Filter for Root?',
    'allowed_protocols' => 'Allowed Protocols',
    'disable_autolinks' => 'Disable Autotags?',
    'clickable_links' => 'Make URLs clickable?',
    'compressed_output' => 'Send compressed output?',
    'frame_options' => 'Protection against "clickjacking"',
    'censormode' => 'Censor Mode?',
    'censorreplace' => 'Censor Replace Text',
    'censorlist' => 'Censor List',
    'ip_lookup' => 'IP Lookup',
    'url_rewrite' => 'Enable URL Rewrite',
    'meta_tags' => 'Meta Tags',
    'meta_description' => 'Default Meta Description',
    'meta_keywords' => 'Default Meta Keywords',
    'default_permissions_block' => 'Block Default Permissions',
    'default_permissions_story' => 'Story Default Permissions',
    'default_permissions_topic' => 'Topic Default Permissions',
    'atom_max_stories' => 'Max. Stories in Webservices Feed',
    'disable_webservices' => 'Disable Webservices?',
    'restrict_webservices' => 'Restrict Webservices?',
    'article_comment_close_enabled' => 'Automatically close comments (default)',
    'article_comment_close_days' => 'Days to close comments (default)',
    'comment_close_rec_stories' => 'Number of most recent stories enabled for comments',
    'allow_reply_notifications' => 'Allow comment reply notifications?',
    'search_style' => 'Results List Style',
    'search_limits' => 'Page Limits',
    'search_show_num' => 'Show Result Number?',
    'search_show_type' => 'Show Result Type?',
    'search_show_sort' => 'Allow User to Sort Results?',
    'search_show_limit' => 'Show Page Limits?',
    'search_separator' => 'Group Separator',
    'search_def_keytype' => 'Default Search Method',
    'search_def_sort' => 'Default Sort Order'
);

$LANG_configsubgroups['Core'] = array(
    'sg_site' => 'Site',
    'sg_stories' => 'Stories and Trackback',
    'sg_theme' => 'Theme',
    'sg_blocks' => 'Blocks',
    'sg_users' => 'Users and Submissions',
    'sg_images' => 'Images',
    'sg_locale' => 'Languages and Locale',
    'sg_misc' => 'Miscellaneous'
);

$LANG_fs['Core'] = array(
    'fs_site' => 'Site',
    'fs_paths' => 'Paths',
    'fs_theme' => 'Theme',
    'fs_mail' => 'Mail',
    'fs_pear' => 'Pear',
    'fs_mysql' => 'MySQL',
    'fs_users' => 'Users',
    'fs_misc' => 'Miscellaneous',
    'fs_spamx' => 'Spam-X',
    'fs_admin_block' => 'Admin Block',
    'fs_locale' => 'Locale',
    'fs_language' => 'Language',
    'fs_debug' => 'Debug',
    'fs_cookies' => 'Cookies',
    'fs_login' => 'Login Settings',
    'fs_search' => 'Search',
    'fs_user_submission' => 'User Submission',
    'fs_submission' => 'Submission Settings',
    'fs_topics_block' => 'Topics Block',
    'fs_whosonline_block' => 'Who\'s Online Block',
    'fs_daily_digest' => 'Daily Digest',
    'fs_whatsnew_block' => 'What\'s New Block',
    'fs_trackback' => 'Trackback',
    'fs_pingback' => 'Pingback',
    'fs_story' => 'Story',
    'fs_theme_advanced' => 'Advanced Settings',
    'fs_syndication' => 'Syndication',
    'fs_imagelib' => 'Image Library',
    'fs_upload' => 'Upload',
    'fs_articleimg' => 'Images in Articles',
    'fs_topicicon' => 'Topic Icons',
    'fs_userphoto' => 'Photos',
    'fs_gravatar' => 'Gravatar',
    'fs_comments' => 'Comments',
    'fs_htmlfilter' => 'HTML Filtering',
    'fs_censoring' => 'Censoring',
    'fs_iplookup' => 'IP Lookup',
    'fs_perm_story' => 'Story Default Permission',
    'fs_perm_topic' => 'Topic Default Permission',
    'fs_perm_block' => 'Block Default Permission',
    'fs_webservices' => 'Webservices'
);

$LANG_configselects['Core'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false),
    2 => array('Reject' => 0, 'Only Keep Latest' => 1, 'Allow Multiple Posts' => 2),
    3 => array('Trackback Enabled' => 0, 'Trackback Disabled' => -1),
    4 => array('Don\'t Check Anything' => 0, 'Check against Site URL' => 1, 'Check full URL' => 2, 'Check against Site URL and full URL' => 3, 'Check IP against Site IP' => 4, 'Check IP and Site URL' => 5, 'Check IP and Full URL' => 6, 'Check IP, Full URL, and Site URL' => 7),
    5 => array('Plain Old Text' => 'plaintext', 'HTML Formatted' => 'html'),
    6 => array('12' => 12, '24' => 24),
    7 => array('Last Page' => 'last', 'First Page' => 'first', 'Every Page' => 'all'),
    8 => array('Right' => 'right', 'Left' => 'left'),
    9 => array('Forward to page' => 'item', 'Display List' => 'list', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    10 => array('None' => '', 'Netpbm' => 'netpbm', 'ImageMagick' => 'imagemagick', 'gdLib' => 'gdlib'),
    11 => array('Flat' => 'flat', 'Nested' => 'nested', 'Threaded' => 'threaded', 'No Comments' => 'nocomment'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3),
    13 => array('Skip' => 0, 'Allow, with speedlimit' => 1, 'Allow, no speedlimit' => 2),
    14 => array('Sunday' => 'Sun', 'Monday' => 'Mon'),
    15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
    16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3),
    19 => array('Google' => 'google', 'Table' => 'table'),
    20 => array('Exact Phrase' => 'phrase', 'All of The Words' => 'all', 'Any of The Words' => 'any'),
    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => ''),
    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2),
    24 => array('Contribute' => 'contribute', 'Home' => 'home', 'Advanced Search' => 'search', 'Directory' => 'directory', 'My Account' => 'prefs', 'Plugin Entries' => 'plugins', 'Custom Entries' => 'custom', 'Site Statistics' => 'stats'),
    25 => array('New Stories' => 'story', 'New Comments' => 'comment', 'New Trackbacks' => 'trackback', 'New Pingbacks' => 'pingback', 'New Users' => 'user'),
    26 => array('G (General Audiences)' => 'G', 'PG (Parental Guidance)' => 'PG', 'R (Restricted)' => 'R', 'X (Explicit)' => 'X'),
    27 => array('Hits (asc)' => 'hits|asc', 'Hits (desc)' => 'hits|desc', 'Date (asc)' => 'date|asc', 'Date (desc)' => 'date|desc', 'Title (asc)' => 'title|asc', 'Title (desc)' => 'title|desc', 'Author (asc)' => 'uid|asc', 'Author (desc)' => 'uid|desc')
);

?>
